@@ -68,6 +68,8 @@ class TestDocument(unittest.TestCase):
             'http://example.com/iframe_src.html',
             'http://example.com/layer_src.png',
             'http://example.com/overlay_src.html',
+            'ftp://ftp.protocol.invalid/',
+            'mailto:user@example.com',
             },
             linked_urls
         )
