@@ -3,8 +3,10 @@ import logging
 import socket
 import tornado.gen
 
+from wpull.cache import Cache
 from wpull.errors import NetworkError, DNSNotFound
 import wpull.util
+import random
 
 
 _logger = logging.getLogger(__name__)
@@ -13,14 +15,19 @@ _logger = logging.getLogger(__name__)
 class Resolver(object):
     IPv4 = socket.AF_INET
     IPv6 = socket.AF_INET6
-    tornado_resolver = tornado.netutil.ThreadedResolver()
+    global_cache = Cache(max_items=100, time_to_live=3600)
 
     def __init__(self, cache_enabled=True, families=(IPv4, IPv6),
-    timeout=None):
-        # TODO: cache
-        self._cache_enabled = cache_enabled
+    timeout=None, rotate=False):
+        if cache_enabled:
+            self._cache = self.global_cache
+        else:
+            self._cache = None
+
         self._families = families
         self._timeout = timeout
+        self._rotate = rotate
+        self._tornado_resolver = tornado.netutil.ThreadedResolver()
 
     @tornado.gen.coroutine
     def resolve(self, host, port):
@@ -29,21 +36,31 @@ class Resolver(object):
         addresses = []
 
         for family in self._families:
+            results = self._get_cache(host, port, family)
+
+            if results is not None:
+                _logger.debug('DNS cache hit.')
+                addresses.extend(results)
+                continue
+
             future = self._resolve_tornado(host, port, family)
             try:
                 results = yield wpull.util.wait_future(future, self._timeout)
             except wpull.util.TimedOut as error:
                 raise NetworkError('DNS resolve timed out') from error
 
-            if results:
-                addresses.extend(results)
+            addresses.extend(results)
+            self._put_cache(host, port, family, results)
 
         if not addresses:
             raise DNSNotFound('DNS resolution did not return any results.')
 
         _logger.debug('Resolved addresses: {0}.'.format(addresses))
 
-        address = addresses[0]
+        if self._rotate:
+            address = random.choice(addresses)
+        else:
+            address = addresses[0]
         _logger.debug('Selected {0} as address.'.format(address))
 
         raise tornado.gen.Return(address)
@@ -52,8 +69,22 @@ class Resolver(object):
     def _resolve_tornado(self, host, port, family):
         _logger.debug('Resolving {0} {1} {2}.'.format(host, port, family))
         try:
-            results = yield self.tornado_resolver.resolve(host, port, family)
+            results = yield self._tornado_resolver.resolve(host, port, family)
             raise tornado.gen.Return(results)
         except socket.error:
             _logger.debug(
                 'Failed to resolve {0} {1} {2}.'.format(host, port, family))
+            raise tornado.gen.Return(())
+
+    def _get_cache(self, host, port, family):
+        if self._cache is None:
+            return None
+
+        key = (host, port, family)
+
+        if key in self._cache:
+            return self._cache[key]
+
+    def _put_cache(self, host, port, family, results):
+        key = (host, port, family)
+        self._cache[key] = results
