@@ -19,6 +19,9 @@ def accept_url(url_info, record_info, verdict, reasons):
     assert record_info['url']
     assert reasons['filters']['HTTPFilter']
 
+    for name, passed in reasons['filters'].items():
+        assert name
+
     if url_info['path'] == '/':
         assert verdict
     elif url_info['path'] == '/test_script':
@@ -32,6 +35,7 @@ def handle_response(url_info, http_info):
     print('handle_response', url_info)
 
     if url_info['path'] == '/':
+        assert http_info['body']['content_size']
         assert http_info['status_code'] == 200
     elif url_info['path'] == '/test_script':
         global injected_url_found
@@ -40,9 +44,9 @@ def handle_response(url_info, http_info):
     return wpull_hook.actions.NORMAL
 
 
-def handle_error(url_info, error):
-    print('handle_response', url_info, error)
-    assert error['error']
+def handle_error(url_info, error_info):
+    print('handle_response', url_info, error_info)
+    assert error_info['error']
     return wpull_hook.actions.NORMAL
 
 
